@@ -1,4 +1,4 @@
-# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of CubicWeb.
@@ -241,7 +241,7 @@ class MultiSelector(Selector):
         for selector in selectors:
             try:
                 selector = _instantiate_selector(selector)
-            except:
+            except Exception:
                 pass
             #assert isinstance(selector, Selector), selector
             if isinstance(selector, cls):
