@@ -42,25 +42,31 @@ class CoreHooksTC(CubicWebTC):
 
     def test_html_tidy_hook(self):
         req = self.request()
-        entity = req.create_entity('Workflow', name=u'wf1', description_format=u'text/html',
-                                 description=u'yo')
+        entity = req.create_entity('Workflow', name=u'wf1',
+                                   description_format=u'text/html',
+                                   description=u'yo')
         self.assertEqual(entity.description, u'yo')
-        entity = req.create_entity('Workflow', name=u'wf2', description_format=u'text/html',
-                                 description=u'<b>yo')
+        entity = req.create_entity('Workflow', name=u'wf2',
+                                   description_format=u'text/html',
+                                   description=u'<b>yo')
         self.assertEqual(entity.description, u'<b>yo</b>')
-        entity = req.create_entity('Workflow', name=u'wf3', description_format=u'text/html',
-                                 description=u'<b>yo</b>')
+        entity = req.create_entity('Workflow', name=u'wf3',
+                                   description_format=u'text/html',
+                                   description=u'<b>yo</b>')
         self.assertEqual(entity.description, u'<b>yo</b>')
-        entity = req.create_entity('Workflow', name=u'wf4', description_format=u'text/html',
-                                 description=u'<b>R&D</b>')
+        entity = req.create_entity('Workflow', name=u'wf4',
+                                   description_format=u'text/html',
+                                   description=u'<b>R&D</b>')
         self.assertEqual(entity.description, u'<b>R&amp;D</b>')
-        entity = req.create_entity('Workflow', name=u'wf5', description_format=u'text/html',
-                                 description=u"<div>c&apos;est <b>l'ét&eacute;")
+        entity = req.create_entity('Workflow', name=u'wf5',
+                                   description_format=u'text/html',
+                                   description=u"<div>c&apos;est <b>l'ét&eacute;")
         self.assertEqual(entity.description, u"<div>c'est <b>l'été</b></div>")
 
     def test_nonregr_html_tidy_hook_no_update(self):
-        entity = self.request().create_entity('Workflow', name=u'wf1', description_format=u'text/html',
-                                 description=u'yo')
+        entity = self.request().create_entity('Workflow', name=u'wf1',
+                                              description_format=u'text/html',
+                                              description=u'yo')
         entity.set_attributes(name=u'wf2')
         self.assertEqual(entity.description, u'yo')
         entity.set_attributes(description=u'R&D<p>yo')
@@ -90,7 +96,8 @@ class CoreHooksTC(CubicWebTC):
         self.assertEqual(entity.owned_by[0].eid, self.session.user.eid)
 
     def test_user_login_stripped(self):
-        u = self.create_user('  joe  ')
+        req = self.request()
+        u = self.create_user(req, '  joe  ')
         tname = self.execute('Any L WHERE E login L, E eid %(e)s',
                              {'e': u.eid})[0][0]
         self.assertEqual(tname, 'joe')
@@ -104,7 +111,8 @@ class CoreHooksTC(CubicWebTC):
 class UserGroupHooksTC(CubicWebTC):
 
     def test_user_synchronization(self):
-        self.create_user('toto', password='hop', commit=False)
+        req = self.request()
+        self.create_user(req, 'toto', password='hop', commit=False)
         self.assertRaises(AuthenticationError,
                           self.repo.connect, u'toto', password='hop')
         self.commit()
@@ -129,7 +137,8 @@ class UserGroupHooksTC(CubicWebTC):
         self.assertEqual(user.groups, set(('managers',)))
 
     def test_user_composite_owner(self):
-        ueid = self.create_user('toto').eid
+        req = self.request()
+        ueid = self.create_user(req, 'toto').eid
         # composite of euser should be owned by the euser regardless of who created it
         self.execute('INSERT EmailAddress X: X address "toto@logilab.fr", U use_email X '
                      'WHERE U login "toto"')
