@@ -344,7 +344,7 @@ class Repository(object):
             self.looping_task(cleanup_session_interval, self.clean_sessions)
         assert isinstance(self._looping_tasks, list), 'already started'
         for i, (interval, func, args) in enumerate(self._looping_tasks):
-            self._looping_tasks[i] = task = utils.LoopTask(interval, func, args)
+            self._looping_tasks[i] = task = utils.LoopTask(self, interval, func, args)
             self.info('starting task %s with interval %.2fs', task.name,
                       interval)
             task.start()
@@ -413,7 +413,7 @@ class Repository(object):
             cnxset = self._cnxsets_pool.get_nowait()
             try:
                 cnxset.close(True)
-            except:
+            except Exception:
                 self.exception('error while closing %s' % cnxset)
                 continue
         if self.pyro_registered:
@@ -791,7 +791,7 @@ class Repository(object):
             return session.commit()
         except (ValidationError, Unauthorized):
             raise
-        except:
+        except Exception:
             self.exception('unexpected error')
             raise
 
@@ -802,7 +802,7 @@ class Repository(object):
             session = self._get_session(sessionid)
             session.set_tx_data(txid)
             session.rollback()
-        except:
+        except Exception:
             self.exception('unexpected error')
             raise
 
@@ -905,7 +905,7 @@ class Repository(object):
         for sessionid in self._sessions.keys():
             try:
                 self.close(sessionid, checkshuttingdown=False)
-            except:
+            except Exception: # XXX BaseException?
                 self.exception('error while closing session %s' % sessionid)
 
     def clean_sessions(self):
