@@ -37,11 +37,11 @@ from cubicweb.server.edition import EditedEntity
 
 def dbg_st_search(uri, union, varmap, args, cachekey=None, prefix='rql for'):
     if server.DEBUG & server.DBG_RQL:
-        print '  %s %s source: %s' % (prefix, uri, union.as_string())
+        print '  %s %s source: %s' % (prefix, uri, repr(union.as_string()))
         if varmap:
             print '    using varmap', varmap
         if server.DEBUG & server.DBG_MORE:
-            print '    args', args
+            print '    args', repr(args)
             print '    cache key', cachekey
             print '    solutions', ','.join(str(s.solutions)
                                             for s in union.children)
@@ -177,7 +177,7 @@ class AbstractSource(object):
         # cw < 3.10 bw compat
         try:
             processed['adapter'] = confdict['adapter']
-        except:
+        except KeyError:
             pass
         # check for unknown options
         if confdict and not confdict.keys() == ['adapter']:
