@@ -412,7 +412,9 @@ class NativeSQLSource(SQLAdapterMixIn, AbstractSource):
     def init(self, activated, source_entity):
         self.init_creating(source_entity._cw.cnxset)
         try:
-            source_entity._cw.system_sql('SELECT COUNT(asource) FROM entities')
+            # test if 'asource' column exists
+            query = self.dbhelper.sql_add_limit_offset('SELECT asource FROM entities', 1)
+            source_entity._cw.system_sql(query)
         except Exception, ex:
             self.eid_type_source = self.eid_type_source_pre_131
 
@@ -1650,7 +1652,7 @@ class DatabaseIndependentBackupRestore(object):
         return self._source.get_connection()
 
     def backup(self, backupfile):
-        archive=zipfile.ZipFile(backupfile, 'w')
+        archive=zipfile.ZipFile(backupfile, 'w', allowZip64=True)
         self.cnx = self.get_connection()
         try:
             self.cursor = self.cnx.cursor()
@@ -1746,7 +1748,7 @@ class DatabaseIndependentBackupRestore(object):
         return dumps((name, columns, rows), pickle.HIGHEST_PROTOCOL)
 
     def restore(self, backupfile):
-        archive = zipfile.ZipFile(backupfile, 'r')
+        archive = zipfile.ZipFile(backupfile, 'r', allowZip64=True)
         self.cnx = self.get_connection()
         self.cursor = self.cnx.cursor()
         sequences, tables, table_chunks = self.read_metadata(archive, backupfile)
